==> nextcloud-15.0.10.tar.bz2: nextcloud/apps/updatenotification/l10n/ko.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version}을(를) 사용할 수 있습니다. 업데이트하는 방법에 대해서 알아보십시오.",
    "Update notifications" : "업데이트 알림",
    "Channel updated" : "채널 업데이트됨",
    "The update server could not be reached since %d days to check for new updates." : "업데이트 서버에 %d일 동안 접근할 수 없어서 새 업데이트를 확인할 수 없습니다.",
    "Please check the Nextcloud and server log files for errors." : "Nextcloud 및 서버 로그에서 오류 정보를 확인하십시오.",
    "Update to %1$s is available." : "%1$s(으)로 업데이트할 수 있습니다.",
    "Update for %1$s to version %2$s is available." : "%1$s을(를) 버전 %2$s(으)로 업데이트할 수 있습니다.",
    "Update for {app} to version %s is available." : "{app}을(를) 버전 %s(으)로 업데이트할 수 있습니다.",
    "Update notification" : "업데이트 알림",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloud 업데이트 알림을 표시하고 업데이터에 SSO를 지원합니다.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "실행 중인 버전이 더 이상 지원되지 않습니다. 빠른 시일 내에 지원되는 버전으로 업데이트하십시오.",
    "Apps missing updates" : "업데이트되지 않은 앱",
    "View in store" : "스토어에서 보기",
    "Apps with available updates" : "업데이트할 수 있는 앱",
    "Open updater" : "업데이터 열기",
    "Download now" : "지금 다운로드",
    "What's new?" : "새로운 항목",
    "The update check is not yet finished. Please refresh the page." : "업데이트 확인이 아직 끝나지 않았습니다. 페이지를 새로 고치십시오.",
    "Your version is up to date." : "최신 버전을 사용하고 있습니다.",
    "A non-default update server is in use to be checked for updates:" : "기본 업데이트 서버가 아닌 곳에서 업데이트를 확인하고 있음:",
    "Update channel:" : "업데이트 채널:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "항상 새 버전으로 업그레이드할 수 있지만, 더 안정적인 버전으로 다운그레이드할 수는 없습니다.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "새 릴리스가 발표된 후 여기에 표시되기까지 시간이 소요됩니다. 새 버전은 단계적으로 적용되고 있으며 문제가 발생한 경우 버전을 건너뛸 수도 있습니다.",
    "Notify members of the following groups about available updates:" : "다음 그룹 구성원에게 업데이트 알림 전달:",
    "Only notification for app updates are available." : "앱 업데이트 알림만 사용할 수 있습니다.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "선택한 업데이트 채널은 서버 알림을 사용하지 않습니다.",
    "The selected update channel does not support updates of the server." : "선택한 업데이트 채널은 서버 업데이트를 지원하지 않습니다.",
    "A new version is available: <strong>{newVersionString}</strong>" : "새 버전을 사용할 수 있음: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate}에 확인함",
    "Checking apps for compatible updates" : "호환되는 앱 업데이트 확인 중",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.php에서 <samp>appstoreenabled</samp> 설정이 false가 아닌지 확인하십시오.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "앱 스토어에 연결할 수 없거나 앱 스토어에서 업데이트 정보를 반환하지 않았습니다. 업데이트를 직접 검색하거나 서버가 인터넷에 연결되어 있고 앱 스토어에 접근할 수 있는지 확인하십시오.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>모든</strong> 앱에 이 버전과 호환되는 업데이트가 있음",
    "View changelog" : "변경 기록 확인",
    "Stable" : "안정판",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "최신 안정 버전입니다. 일반 사용에 적합하며 항상 최신 주 버전으로 업데이트됩니다.",
    "Production" : "프로덕션",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "최신 패치 수준으로 업데이트되지만 다음 주 릴리스로 곧바로 업데이트되지는 않습니다. 해당 업데이트는 대개의 경우 두 번째 부 릴리스(x.0.2)에 진행되며 인스턴스의 버전이 최신 부 버전일 때에만 진행됩니다.",
    "Beta" : "베타",
    "A pre-release version only for testing new features, not for production environments." : "새로운 기능을 테스트하는 출시 이전 버전이며, 프로덕션 환경에 적합하지 않습니다.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["앱 <strong>%n</strong>개는 이 버전과 호환되는 업데이트가 없음"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "항상 새로운 버전이나 실험 채널로 업그레이드할 수 있지만, 안정 채널로 다운그레이드할 수는 없습니다.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>프로덕션</strong>은 최신 패치 수준으로 업데이트되지만 다음 주 릴리스로 곧바로 업데이트되지는 않습니다. 해당 업데이트는 대개의 경우 두 번째 부 릴리스(x.0.2)에 진행되며 인스턴스의 버전이 최신 부 버전일 때에만 진행됩니다.",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>안정판</strong>은 최신 안정 버전입니다. 일반 사용에 적합하며 항상 최신 주 버전으로 업데이트됩니다.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>베타</strong>는 새로운 기능을 테스트하는 출시 이전 버전이며, 프로덕션 환경에 적합하지 않습니다.",
    "Could not start updater, please try the manual update" : "업데이트를 시작할 수 없습니다. 수동 업데이트를 시도하십시오."
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/updatenotification/l10n/ko.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version}을(를) 사용할 수 있습니다. 업데이트하는 방법에 대해서 알아보십시오.",
    "Channel updated" : "채널 업데이트됨",
    "Update notifications" : "업데이트 알림",
    "The update server could not be reached since %d days to check for new updates." : "업데이트 서버에 %d일 동안 접근할 수 없어서 새 업데이트를 확인할 수 없습니다.",
    "Please check the Nextcloud and server log files for errors." : "Nextcloud 및 서버 로그에서 오류 정보를 확인하십시오.",
    "Update to %1$s is available." : "%1$s(으)로 업데이트할 수 있습니다.",
    "Update for %1$s to version %2$s is available." : "%1$s을(를) 버전 %2$s(으)로 업데이트할 수 있습니다.",
    "Update for {app} to version %s is available." : "{app}을(를) 버전 %s(으)로 업데이트할 수 있습니다.",
    "Update notification" : "업데이트 알림",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloud 업데이트 알림을 표시하고 업데이터에 SSO를 지원합니다.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "실행 중인 버전이 더 이상 지원되지 않습니다. 빠른 시일 내에 지원되는 버전으로 업데이트하십시오.",
    "Apps missing updates" : "업데이트되지 않은 앱",
    "View in store" : "스토어에서 보기",
    "Apps with available updates" : "업데이트할 수 있는 앱",
    "Open updater" : "업데이터 열기",
    "Download now" : "지금 다운로드",
    "What's new?" : "새로운 항목",
    "The update check is not yet finished. Please refresh the page." : "업데이트 확인이 아직 끝나지 않았습니다. 페이지를 새로 고치십시오.",
    "Your version is up to date." : "최신 버전을 사용하고 있습니다.",
    "A non-default update server is in use to be checked for updates:" : "기본 업데이트 서버가 아닌 곳에서 업데이트를 확인하고 있음:",
    "Update channel:" : "업데이트 채널:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "항상 새 버전으로 업그레이드할 수 있지만, 더 안정적인 버전으로 다운그레이드할 수는 없습니다.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "새 릴리스가 발표된 후 여기에 표시되기까지 시간이 소요됩니다. 새 버전은 단계적으로 적용되고 있으며 문제가 발생한 경우 버전을 건너뛸 수도 있습니다.",
    "Notify members of the following groups about available updates:" : "다음 그룹 구성원에게 업데이트 알림 전달:",
    "Only notification for app updates are available." : "앱 업데이트 알림만 사용할 수 있습니다.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "선택한 업데이트 채널은 서버 알림을 사용하지 않습니다.",
    "The selected update channel does not support updates of the server." : "선택한 업데이트 채널은 서버 업데이트를 지원하지 않습니다.",
    "A new version is available: <strong>{newVersionString}</strong>" : "새 버전을 사용할 수 있음: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate}에 확인함",
    "Checking apps for compatible updates" : "호환되는 앱 업데이트 확인 중",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.php에서 <samp>appstoreenabled</samp> 설정이 false가 아닌지 확인하십시오.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "앱 스토어에 연결할 수 없거나 앱 스토어에서 업데이트 정보를 반환하지 않았습니다. 업데이트를 직접 검색하거나 서버가 인터넷에 연결되어 있고 앱 스토어에 접근할 수 있는지 확인하십시오.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>모든</strong> 앱에 이 버전과 호환되는 업데이트가 있음",
    "View changelog" : "변경 기록 확인",
    "Stable" : "안정판",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "최신 안정 버전입니다. 일반 사용에 적합하며 항상 최신 주 버전으로 업데이트됩니다.",
    "Beta" : "베타",
    "A pre-release version only for testing new features, not for production environments." : "새로운 기능을 테스트하는 출시 이전 버전이며, 프로덕션 환경에 적합하지 않습니다.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["앱 <strong>%n</strong>개는 이 버전과 호환되는 업데이트가 없음"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "항상 새로운 버전이나 실험 채널로 업그레이드할 수 있지만, 안정 채널로 다운그레이드할 수는 없습니다.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>프로덕션</strong>은 최신 패치 수준으로 업데이트되지만 다음 주 릴리스로 곧바로 업데이트되지는 않습니다. 해당 업데이트는 대개의 경우 두 번째 부 릴리스(x.0.2)에 진행되며 인스턴스의 버전이 최신 부 버전일 때에만 진행됩니다.",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>안정판</strong>은 최신 안정 버전입니다. 일반 사용에 적합하며 항상 최신 주 버전으로 업데이트됩니다.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>베타</strong>는 새로운 기능을 테스트하는 출시 이전 버전이며, 프로덕션 환경에 적합하지 않습니다.",
    "Could not start updater, please try the manual update" : "업데이트를 시작할 수 없습니다. 수동 업데이트를 시도하십시오.",
    "Production" : "프로덕션",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "최신 패치 수준으로 업데이트되지만 다음 주 릴리스로 곧바로 업데이트되지는 않습니다. 해당 업데이트는 대개의 경우 두 번째 부 릴리스(x.0.2)에 진행되며 인스턴스의 버전이 최신 부 버전일 때에만 진행됩니다."
},
"nplurals=1; plural=0;");
